@@ -3,11 +3,11 @@
 static int _xlvl = 0;
 char *_xlvl_type[256];
 
-int XMLDEF_(char *name, const char *format, ...) {
+static int XMLDEF_(char *name, const char *format, ...) {
 	va_list argp;
 	XMLINDENT;
 	printf("<%s>", name);
-	
+
 	va_start(argp, format);
 	vprintf(format, argp);
 	va_end(argp);
@@ -15,42 +15,44 @@ int XMLDEF_(char *name, const char *format, ...) {
 	return 0;
 }
 
-// int XMLBOX_(char *name) {
-//	XMLINDENT;
-//	printf("<%s>\n", name);
-//	_xlvl++; 
-//	_xlvl_type[_xlvl] = malloc(20 * sizeof(char));
-//	sprintf(_xlvl_type[_xlvl], "</%s>", name);
-//	return 0;
-//}
+/*
+static int XMLBOX_(char *name) {
+	XMLINDENT;
+	printf("<%s>\n", name);
+	_xlvl++;
+	_xlvl_type[_xlvl] = malloc(20 * sizeof(char));
+	sprintf(_xlvl_type[_xlvl], "</%s>", name);
+	return 0;
+}
 
-//void XMLRETURN_()  {
-//	_xlvl--; 
-//	XMLINDENT;
-//	printf("%s\n", _xlvl_type[_xlvl+1] );
-//	free(_xlvl_type[_xlvl+1]);
-//}
+static void XMLRETURN_(void)  {
+	_xlvl--;
+	XMLINDENT;
+	printf("%s\n", _xlvl_type[_xlvl+1] );
+	free(_xlvl_type[_xlvl+1]);
+}
+*/
 
-void XMLBOX_(char *name) {
+static void XMLBOX_(char *name) {
 	XMLINDENT;
 	printf("<%s>\n", name);
 	_xlvl++;
 	_xlvl_type[_xlvl] = name;
 }
 
-void XMLRETURN_()  {
+static void XMLRETURN_(void)  {
 	_xlvl--;
 	XMLINDENT;
 	printf("</%s>\n", _xlvl_type[_xlvl+1]);
 }
 
 
-void XMLSTART_() {
+static void XMLSTART_(void) {
 	printf("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
 	XMLBOX("lsdvd");
 }
 
-void XMLSTOP_() {
+static void XMLSTOP_(void) {
 	while(_xlvl) XMLRETURN;
 }
 
@@ -67,7 +69,7 @@ void oxml_print(struct dvd_info *dvd_info) {
 	{
 	if ( opt_t == j+1 || opt_t == 0 ) {
 
-	// GENERAL
+	/* GENERAL */
 	if (dvd_info->titles[j].enabled) {
 
 		XMLBOX("track");
@@ -85,8 +87,8 @@ void oxml_print(struct dvd_info *dvd_info) {
 			XMLDEF("height", "%s", dvd_info->titles[j].parameter.height);
 			XMLDEF("df", "%s", dvd_info->titles[j].parameter.df);
 		}
-		
-		// PALETTE
+
+		/* PALETTE */
 		if (dvd_info->titles[j].palette != NULL ) {
 			XMLBOX("palette");
 			for (i=0; i < 16; i++) {
@@ -95,12 +97,12 @@ void oxml_print(struct dvd_info *dvd_info) {
 			XMLRETURN;
 		}
 
-		// ANGLES
-		if (dvd_info->titles[j].angle_count) { // poor check, but there's no other info anyway.
+		/* ANGLES */
+		if (dvd_info->titles[j].angle_count) { /* poor check, but there's no other info anyway. */
 			XMLDEF("angles", "%d", dvd_info->titles[j].angle_count);
 		}
 
-		// AUDIO
+		/* AUDIO */
 		if (dvd_info->titles[j].audiostreams != NULL ) {
 			for (i=0; i<dvd_info->titles[j].audiostream_count; i++)
 			{
@@ -119,7 +121,7 @@ void oxml_print(struct dvd_info *dvd_info) {
 			}
 		}
 
-		// CHAPTERS
+		/* CHAPTERS */
 		if (dvd_info->titles[j].chapters != NULL) {
 			for (i=0; i<dvd_info->titles[j].chapter_count; i++)
 			{
@@ -131,7 +133,7 @@ void oxml_print(struct dvd_info *dvd_info) {
 			}
 		}
 
-		// CELLS
+		/* CELLS */
 		if (dvd_info->titles[j].cells != NULL) {
 			for (i=0; i<dvd_info->titles[j].cell_count; i++)
 			{
@@ -142,7 +144,7 @@ void oxml_print(struct dvd_info *dvd_info) {
 			}
 		}
 
-		// SUBTITLES
+		/* SUBTITLES */
 		if (dvd_info->titles[j].subtitles != NULL) {
 			for (i=0; i<dvd_info->titles[j].subtitle_count; i++)
 			{
@@ -155,7 +157,7 @@ void oxml_print(struct dvd_info *dvd_info) {
 				XMLRETURN;
 			}
 		}
-	XMLRETURN;	
+	XMLRETURN;
 	}
 	}
 	}
